import { requestPostFetch } from "@/utils/fetch";

interface SignInWithCredentials {
  email: string;
  password: string;
}

export async function signInWithCredentials({
  email,
  password,
}: SignInWithCredentials) {
  try {
    const response = await requestPostFetch({
      path: `v1/auth/login`,
      data: {
        email: email,
        password: password,
      },
      token: "",
    });
    console.log("*************** error 2 ***************", response);

    return response.data;
  } catch (error: any) {
    console.log("*************** error 3 ***************", error);
    throw new Error(error.message);
  }
}

interface SignUpWithCredentials {
  first_name: string;
  last_name: string;
  email: string;
  password: string;
  confirm_password: string;
}

export async function signUpWithCredentials({
  first_name,
  last_name,
  email,
  password,
  confirm_password,
}: SignUpWithCredentials) {
  try {
    const response = await requestPostFetch({
      path: `v1/auth/register`,
      data: {
        first_name,
        last_name,
        email,
        password,
        confirm_password,
      },
      token: "",
    });

    return response.data;
  } catch (error: any) {
    throw new Error(error.message);
  }
}

interface ForgotPassword {
  email: string;
}

export async function ForgotPassword({
  email,
}: ForgotPassword) {
  try {
    const response = await requestPostFetch({
      path: `v1/auth/forgot-password`,
      data: {
        email: email,
      },
      token: "",
    });
    return response.data;
  } catch (error: any) {
    throw new Error(error.message);
  }
}

interface VerifyOtp {
  otp: string;
  reset_token: string;
}

export async function VerifyOtp({
  otp,
  reset_token
}: VerifyOtp) {
  try {
    const response = await requestPostFetch({
      path: `v1/auth/check-otp`,
      data: {
        otp: otp,
        reset_token: reset_token
      },
      token: "",
    });
    return response.data;
  } catch (error: any) {
    throw new Error(error.message);
  }
}

interface ResetPassword {
  password: string;
  confirm_password: string;
  reset_token: string;
}

export async function ResetPassword({
  password,
  confirm_password,
  reset_token,
}: ResetPassword) {
  try {
    const response = await requestPostFetch({
      path: `v1/auth/reset-password`,
      data: {
        password,
        confirm_password,
        reset_token
      },
      token: "",
    });
    return response.data;
  } catch (error: any) {
    throw new Error(error.message);
  }
}

